import { ServiceFactory } from "app/services/service-factory";
import { PbCloison, PreBarrage } from "jalhyd";
import { SelectEntry } from "./select-entry";
import { SelectField } from "./select-field";

/*
    "id": "select_upstream_basin",
    "type": "select_custom",
    "source": "upstream_basin"
*/

// PbCloisons, bassin amont
export class SelectFieldUpstreamBasin extends SelectField {
    protected populate() {
        const pbWallU = this.parentForm.currentNub as PbCloison;
        const preBarrageU = pbWallU.parent as PreBarrage;
        const posDb = pbWallU.bassinAval?.findPositionInParent();
        // river upstream
        this.addEntry(
            new SelectEntry(
                this._entriesBaseId + "none",
                undefined,
                ServiceFactory.i18nService.localizeText("INFO_LIB_AMONT")
            )
        );
        // all available basins, depending on current downstream basin
        for (const b of preBarrageU.bassins) {
            const pos = b.findPositionInParent();
            if (posDb === undefined || pos < posDb) {
                this.addEntry(
                    new SelectEntry(
                        this._entriesBaseId + b.uid,
                        b.uid,
                        ServiceFactory.i18nService.localizeMessage(b.description)
                    )
                );
            }
        }
    }

    protected initSelectedValue() {
        const ub = (this.nub as PbCloison).bassinAmont;
        this.setValueFromId(this._entriesBaseId + (ub ? ub.uid : "none"));
    }

    public get associatedProperty(): string {
        return undefined;
    }

    public get configDefaultValue(): string {
        return undefined;
    }
}